aboutsummaryrefslogtreecommitdiff
path: root/src/dsp/dsp.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dsp/dsp.h')
-rw-r--r--src/dsp/dsp.h24
1 files changed, 16 insertions, 8 deletions
diff --git a/src/dsp/dsp.h b/src/dsp/dsp.h
index fcbac3a..153db7f 100644
--- a/src/dsp/dsp.h
+++ b/src/dsp/dsp.h
@@ -17,7 +17,7 @@
#ifndef LIBGAV1_SRC_DSP_DSP_H_
#define LIBGAV1_SRC_DSP_DSP_H_
-#include <cstddef> // ptrdiff_t
+#include <cstddef>
#include <cstdint>
#include <cstdlib>
@@ -372,8 +372,9 @@ using SuperResCoefficientsFunc = void (*)(int upscaled_width,
// |coefficients| is the upscale filter used by each pixel in a row. It is not
// used by the C function.
// |source| is the input frame buffer. It will be line extended.
+// |source_stride| is given in pixels.
// |dest| is the output buffer.
// |stride| is given in pixels, and shared by |source| and |dest|.
// |height| is the height of the block to be processed.
// |downscaled_width| is the width of the input frame.
// |upscaled_width| is the width of the output frame.
@@ -381,9 +382,10 @@ using SuperResCoefficientsFunc = void (*)(int upscaled_width,
// pixel.
// |initial_subpixel_x| is a base offset from which |step| increments.
using SuperResFunc = void (*)(const void* coefficients, void* source,
- ptrdiff_t stride, int height,
+ ptrdiff_t source_stride, int height,
int downscaled_width, int upscaled_width,
- int initial_subpixel_x, int step, void* dest);
+ int initial_subpixel_x, int step, void* dest,
+ ptrdiff_t dest_stride);
// Loop restoration function signature. Sections 7.16, 7.17.
// |restoration_info| contains loop restoration information, such as filter
@@ -391,14 +393,15 @@ using SuperResFunc = void (*)(const void* coefficients, void* source,
// |source| is the input frame buffer, which is deblocked and cdef filtered.
// |top_border| and |bottom_border| are the top and bottom borders.
// |dest| is the output.
// |stride| is given in pixels, and shared by |source|, |top_border|,
// |bottom_border| and |dest|.
// |restoration_buffer| contains buffers required for self guided filter and
// wiener filter. They must be initialized before calling.
using LoopRestorationFunc = void (*)(
const RestorationUnitInfo& restoration_info, const void* source,
- const void* top_border, const void* bottom_border, ptrdiff_t stride,
- int width, int height, RestorationBuffer* restoration_buffer, void* dest);
+ ptrdiff_t stride, const void* top_border, ptrdiff_t top_border_stride,
+ const void* bottom_border, ptrdiff_t bottom_border_stride, int width,
+ int height, RestorationBuffer* restoration_buffer, void* dest);
// Index 0 is Wiener Filter.
// Index 1 is Self Guided Restoration Filter.
@@ -900,6 +903,11 @@ namespace dsp_internal {
(LIBGAV1_ENABLE_ALL_DSP_FUNCTIONS || \
LIBGAV1_Dsp10bpp_##func == LIBGAV1_CPU_SSE4_1)
+// Initializes C-only function pointers. Note some entries may be set to
+// nullptr if LIBGAV1_ENABLE_ALL_DSP_FUNCTIONS is not defined. This is meant
+// for use in tests only, it is not thread-safe.
+void DspInit_C();
+
// Returns the appropriate Dsp table for |bitdepth| or nullptr if one doesn't
// exist. This version is meant for use by test or dsp/*Init() functions only.
dsp::Dsp* GetWritableDspTable(int bitdepth);
@@ -372,8 +372,9 @@ using SuperResCoefficientsFunc = void (*)(int upscaled_width,
// |dest| is the output buffer.
-// |stride| is given in pixels, and shared by |source| and |dest|.
+// |dest_stride| is given in pixels.
// |height| is the height of the block to be processed.
// |downscaled_width| is the width of the input frame.
@@ -391,14 +393,15 @@ using SuperResFunc = void (*)(const void* coefficients, void* source,
// |top_border| and |bottom_border| are the top and bottom borders.
// |dest| is the output.
-// |stride| is given in pixels, and shared by |source|, |top_border|,
-// |bottom_border| and |dest|.
+// |stride| is given in pixels, and shared by |source| and |dest|.
+// |top_border_stride| and |bottom_border_stride| are given in pixels.
// |restoration_buffer| contains buffers required for self guided filter and
// wiener filter. They must be initialized before calling.